import request from '@/utils/request'
// 查询支付记录列表
export function listJxHorizonPay(query) {
  return request({
    url: '/jx_horizon/jxHorizonPay/list',
    method: 'get',
    params: query
  })
}
// 查询支付记录详细
export function getJxHorizonPay(id) {
  return request({
    url: '/jx_horizon/jxHorizonPay/get',
    method: 'get',
    params: {
     id: id.toString()
    }
  })
}
// 新增支付记录
export function addJxHorizonPay(data) {
  return request({
    url: '/jx_horizon/jxHorizonPay/add',
    method: 'post',
    data: data
  })
}
// 修改支付记录
export function updateJxHorizonPay(data) {
  return request({
    url: '/jx_horizon/jxHorizonPay/edit',
    method: 'put',
    data: data
  })
}
// 删除支付记录
export function delJxHorizonPay(ids) {
  return request({
    url: '/jx_horizon/jxHorizonPay/delete',
    method: 'delete',
    data:{
       ids:ids
    }
  })
}
// 支付记录支付状态修改
export function changeJxHorizonPayStatus(id,status) {
  const data = {
    id,
    status
  }
  return request({
    url: '/jx_horizon/jxHorizonPay/changeStatus',
    method: 'put',
    data:data
  })
}
// 支付记录平台状态修改
export function changeJxHorizonPayVendorStatus(id,vendorStatus) {
  const data = {
    id,
    vendorStatus
  }
  return request({
    url: '/jx_horizon/jxHorizonPay/changeVendorStatus',
    method: 'put',
    data:data
  })
}