<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" label-width="68px">    
      <el-form-item label="当前系统id" prop="orderId">
        <el-input
            v-model="queryParams.orderId"
            placeholder="请输入当前系统id"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>    
      <el-form-item label="支付方式" prop="payType">
        <el-select v-model="queryParams.payType" placeholder="请选择支付方式" clearable size="small">
            <el-option
                v-for="dict in payTypeOptions"
                :key="dict.key"
                :label="dict.value"
                :value="dict.key"
            />
        </el-select>
      </el-form-item>    
        <el-form-item label="平台支付类" prop="vendorPayType">
          <el-select v-model="queryParams.vendorPayType" placeholder="请选择平台支付类" clearable size="small">
              <el-option label="请选择字典生成" value="" />
          </el-select>
        </el-form-item>    
      <el-form-item label="平台订单ID" prop="vendorOrderId">
        <el-input
            v-model="queryParams.vendorOrderId"
            placeholder="请输入平台订单ID"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>    
      <el-form-item label="支付状态" prop="status">
        <el-select v-model="queryParams.status" placeholder="请选择支付状态" clearable size="small">
            <el-option
                v-for="dict in statusOptions"
                :key="dict.key"
                :label="dict.value"
                :value="dict.key"
            />
        </el-select>
      </el-form-item>    
        <el-form-item label="平台状态" prop="vendorStatus">
          <el-select v-model="queryParams.vendorStatus" placeholder="请选择平台状态" clearable size="small">
              <el-option label="请选择字典生成" value="" />
          </el-select>
        </el-form-item>    
      <el-form-item label="支付完成时间" prop="finishedAt">
        <el-date-picker
            clearable size="small" style="width: 200px"
            v-model="queryParams.finishedAt"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="选择支付完成时间">
        </el-date-picker>
      </el-form-item>    
      <el-form-item label="支付金额" prop="payFee">
        <el-input
            v-model="queryParams.payFee"
            placeholder="请输入支付金额"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>    
      <el-form-item label="原始支付订单ID" prop="prepayId">
        <el-input
            v-model="queryParams.prepayId"
            placeholder="请输入原始支付订单ID"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>      
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索99</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['jx_horizon/jxHorizonPay/add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['jx_horizon/jxHorizonPay/edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['jx_horizon/jxHorizonPay/delete']"
        >删除</el-button>
      </el-col>
    </el-row>
    <el-table v-loading="loading" :data="jxHorizonPayList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />      
      <el-table-column label="系统id" align="center" prop="id" />      
      <el-table-column label="当前系统id" align="center" prop="orderId" />      
      <el-table-column label="支付方式" align="center" prop="payType" :formatter="payTypeFormat" />      
      <el-table-column label="平台支付类" align="center" prop="vendorPayType" />      
      <el-table-column label="平台订单ID" align="center" prop="vendorOrderId" />      
      <el-table-column label="支付状态" align="center">
        <template slot-scope="scope">
            <el-switch
              v-model="scope.row.status"
              :active-value="1"
              :inactive-value="0"
              @change="statusChange(scope.row)"
            ></el-switch>
        </template>
      </el-table-column>      
      <el-table-column label="平台状态" align="center">
        <template slot-scope="scope">
            <el-switch
              v-model="scope.row.vendorStatus"
              :active-value="1"
              :inactive-value="0"
              @change="vendorStatusChange(scope.row)"
            ></el-switch>
        </template>
      </el-table-column>      
      <el-table-column label="支付完成时间" align="center" prop="finishedAt" width="180">
        <template slot-scope="scope">
            <span>{{ parseTime(scope.row.finishedAt, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>      
      <el-table-column label="支付金额" align="center" prop="payFee" />      
      <el-table-column label="原始支付订单ID" align="center" prop="prepayId" />      
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['jx_horizon/jxHorizonPay/edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['jx_horizon/jxHorizonPay/delete']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
    <!-- 添加或修改支付记录对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" append-to-body :close-on-click-modal="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">      
      <el-form-item label="系统用户ID" prop="userId">
           <el-input v-model="form.userId" placeholder="请输入系统用户ID" />
      </el-form-item>      
      <el-form-item label="当前系统id" prop="orderId">
           <el-input v-model="form.orderId" placeholder="请输入当前系统id" />
      </el-form-item>      
      <el-form-item label="支付方式" prop="payType">
          <el-select v-model="form.payType" placeholder="请选择支付方式">
              <el-option
                  v-for="dict in payTypeOptions"
                  :key="dict.key"
                  :label="dict.value"                  
                      :value="dict.key"                  
              ></el-option>
          </el-select>
      </el-form-item>      
      <el-form-item label="平台支付类" prop="vendorPayType">
          <el-select v-model="form.vendorPayType" placeholder="请选择平台支付类">
              <el-option label="请选择字典生成" value="" />
          </el-select>
      </el-form-item>      
      <el-form-item label="平台订单ID" prop="vendorOrderId">
           <el-input v-model="form.vendorOrderId" placeholder="请输入平台订单ID" />
      </el-form-item>      
       <el-form-item label="支付状态" prop="status">
           <el-radio-group v-model="form.status">
               <el-radio
                v-for="dict in statusOptions"
                :key="dict.key"
                :label="dict.key"
               >{{dict.value }}</el-radio>
           </el-radio-group>
       </el-form-item>      
       <el-form-item label="平台状态" prop="vendorStatus">
           <el-radio-group v-model="form.vendorStatus">
               <el-radio label="1">请选择字典生成</el-radio>
           </el-radio-group>
       </el-form-item>      
       <el-form-item label="支付完成时间" prop="finishedAt">
           <el-date-picker clearable size="small" style="width: 200px"
               v-model="form.finishedAt"
               type="date"
               value-format="yyyy-MM-dd"
               placeholder="选择支付完成时间">
           </el-date-picker>
       </el-form-item>      
      <el-form-item label="支付金额" prop="payFee">
           <el-input v-model="form.payFee" placeholder="请输入支付金额" />
      </el-form-item>      
      <el-form-item label="原始支付订单ID" prop="prepayId">
           <el-input v-model="form.prepayId" placeholder="请输入原始支付订单ID" />
      </el-form-item>      
      <el-form-item label="支付事务id" prop="transactionId">
           <el-input v-model="form.transactionId" placeholder="请输入支付事务id" />
      </el-form-item>      
      <el-form-item label="详细支付数据" prop="originalData">
           <el-input v-model="form.originalData" placeholder="请输入详细支付数据" />
      </el-form-item>       
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>
<script>
import {
    listJxHorizonPay,
    getJxHorizonPay,
    delJxHorizonPay,
    addJxHorizonPay,
    updateJxHorizonPay,    
    changeJxHorizonPayStatus,    
    changeJxHorizonPayVendorStatus,    
} from "@/api/jx_horizon/jxHorizonPay";
export default {
  components:{    
  },
  name: "JxHorizonPay",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 总条数
      total: 0,
      // 支付记录表格数据
      jxHorizonPayList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,      
      // payTypeOptions字典数据
      payTypeOptions: [],      
      // statusOptions字典数据
      statusOptions: [],      
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        createdAt: undefined,
        orderId: undefined,
        payType: undefined,
        vendorPayType: undefined,
        vendorOrderId: undefined,
        status: undefined,
        vendorStatus: undefined,
        finishedAt: undefined,
        payFee: undefined,
        prepayId: undefined,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: { 
        createdAt : [
          { required: true, message: "创建时间不能为空", trigger: "blur" }
        ],
        orderId : [
          { required: true, message: "当前系统id不能为空", trigger: "blur" }
        ],
        payType : [
          { required: true, message: "支付方式不能为空", trigger: "blur" }
        ],
        vendorPayType : [
          { required: true, message: "平台支付类不能为空", trigger: "blur" }
        ],
        vendorOrderId : [
          { required: true, message: "平台订单ID不能为空", trigger: "blur" }
        ],
        status : [
          { required: true, message: "支付状态不能为空", trigger: "blur" }
        ],
        vendorStatus : [
          { required: true, message: "平台状态不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {    
    this.getDicts("sys_pay_path").then(response => {
      this.payTypeOptions = response.data.values||[];
    });    
    this.getDicts("sys_pay_status").then(response => {
      this.statusOptions = response.data.values||[];
    });
    this.getList();
  },
  methods: {    
    // 支付状态修改
    statusChange(row) {
      let text = row.status === 1 ? "启用" : "停用";
      this.$confirm('确认要"' + text + '"：吗?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return changeJxHorizonPayStatus(row.id, row.status);
        }).then(() => {
          this.msgSuccess(text + "成功");
        }).catch(function() {
          row.userStatus =row.userStatus === 0 ?1 : 0;
        });
    },    
    // 平台状态修改
    vendorStatusChange(row) {
      let text = row.vendorStatus === 1 ? "启用" : "停用";
      this.$confirm('确认要"' + text + '"：吗?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return changeJxHorizonPayVendorStatus(row.id, row.vendorStatus);
        }).then(() => {
          this.msgSuccess(text + "成功");
        }).catch(function() {
          row.userStatus =row.userStatus === 0 ?1 : 0;
        });
    },    
    /** 查询支付记录列表 */
    getList() {
      this.loading = true;
      listJxHorizonPay(this.queryParams).then(response => {
        let list = response.data.list || [];        
        this.jxHorizonPayList = list;        
        this.total = response.data.total;
        this.loading = false;
      });
    },    
    // 支付方式字典翻译
    payTypeFormat(row, column) {
      return this.selectDictLabel(this.payTypeOptions, row.payType);
    },    
    // 支付状态字典翻译
    statusFormat(row, column) {
      return this.selectDictLabel(this.statusOptions, row.status);
    },    
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {        
        createdAt: undefined,        
        updatedAt: undefined,        
        id: undefined,        
        userId: undefined,        
        orderId: undefined,        
        payType: undefined,        
        vendorPayType: undefined,        
        vendorOrderId: undefined,        
        status: "0" ,        
        vendorStatus: "0" ,        
        finishedAt: undefined,        
        payFee: undefined,        
        prepayId: undefined,        
        transactionId: undefined,        
        originalData: undefined,        
      };      
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!=1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加支付记录";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getJxHorizonPay(id).then(response => {
        let data = response.data;        
        data.payType = ''+data.payType        
        data.vendorPayType = ''+data.vendorPayType        
        data.status = ''+data.status        
        data.vendorStatus = ''+data.vendorStatus        
        this.form = data;
        this.open = true;
        this.title = "修改支付记录";
      });
    },
    /** 提交按钮 */
    submitForm: function() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != undefined) {
            updateJxHorizonPay(this.form).then(response => {
              if (response.code === 0) {
                this.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              } else {
                this.msgError(response.msg);
              }
            });
          } else {
            addJxHorizonPay(this.form).then(response => {
              if (response.code === 0) {
                this.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              } else {
                this.msgError(response.msg);
              }
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm('是否确认删除支付记录编号为"' + ids + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delJxHorizonPay(ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(function() {});
    }
  }
};
</script>
<style>
</style>